﻿using System;
using System.Linq;
using System.Windows;
using SpotnetWatchdog.Resources;
using SpotnetWatchdog.Utils;
using SpotnetWatchdog.ViewModels;

namespace SpotnetWatchdog
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        protected override void OnStartup(StartupEventArgs e)
        {
            try
            {
                if (SingleInstance.Start()) //only start if this instance of the application is the only one
                {
                    base.OnStartup(e);

                    bool showWatchResults = e.Args.Any((arg) => arg == "-swr");
                    MainWindow window = new MainWindow()
                    {
                        DataContext = new MainWindowViewModel(showWatchResults)
                    };

                    window.Show();

                    SingleInstance.Stop();
                }
                else
                {
                    SingleInstance.ShowFirstInstance();
                    Shutdown(0);
                }
            }
            catch (Exception ex)
            {
                HandleException(ex);
            }
        }

        /// <summary>
        /// Is triggered when an Exception is thrown and not handled
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Application_DispatcherUnhandledException(object sender, System.Windows.Threading.DispatcherUnhandledExceptionEventArgs e)
        {
            HandleException(e.Exception);

            Shutdown(1);

            e.Handled = true;
        }

        private void HandleException(Exception ex)
        {
            MessageBox.Show(string.Format(Messages.UnexpectedError, ex.Message), Messages.UnexpectedError
                , MessageBoxButton.OK, MessageBoxImage.Error);

            Shutdown(1);
        }
    }
}
